@@ -87,7 +87,7 @@ private slots:
 	void initaRtsConnections();
 };
 
-#include <artsactions.h>
+#include "artsactions.h"
 
 class MainWindow : public KMainWindow {
 	Q_OBJECT
