@@ -34,6 +34,7 @@
 #include "cache.h"
 #include "playlistsplitter.h"
 #include "collectionlist.h"
+#include "covermanager.h"
 #include "tagtransactionmanager.h"
 
 using namespace ActionCollection;
@@ -67,11 +68,11 @@ JuK::JuK(QWidget *parent, const char *name) :
     readConfig();
     setupSystemTray();
     setupGlobalAccels();
-    processArgs();
     createDirs();
 
     SplashScreen::finishedLoading();
     QTimer::singleShot(0, CollectionList::instance(), SLOT(slotCheckCache()));
+    QTimer::singleShot(0, this, SLOT(slotProcessArgs()));
 
     m_sliderAction->slotUpdateOrientation();
 }
@@ -119,6 +120,8 @@ void JuK::setupActions()
     KStdAction::clear(kapp, SLOT(clear()), actions());
     KStdAction::selectAll(kapp, SLOT(selectAll()), actions());
 
+    new KAction(i18n("Remove From Playlist"), "edit_remove", 0, kapp, SLOT(clear()), actions(), "removeFromPlaylist");
+
     KActionMenu *actionMenu = new KActionMenu(i18n("&Random Play"), "roll", actions(), "actionMenu");
     actionMenu->setDelayed(false);
 
@@ -139,8 +142,8 @@ void JuK::setupActions()
     new KAction(i18n("P&ause"), "player_pause", 0, m_player, SLOT(pause()), actions(), "pause");
     new KAction(i18n("&Stop"),  "player_stop",  0, m_player, SLOT(stop()),  actions(), "stop");
 
-    new KToolBarPopupAction(i18n("Previous &Track"), "player_start", KShortcut(), m_player, SLOT(back()), actions(), "back");
-    new KAction(i18n("&Next Track"), "player_end", KShortcut(), m_player, SLOT(forward()), actions(), "forward");
+    new KToolBarPopupAction(i18n("previous track", "Previous"), "player_start", KShortcut(), m_player, SLOT(back()), actions(), "back");
+    new KAction(i18n("next track", "&Next"), "player_end", KShortcut(), m_player, SLOT(forward()), actions(), "forward");
     new KToggleAction(i18n("&Loop Playlist"), 0, KShortcut(), actions(), "loopPlaylist");
     KToggleAction *resizeColumnAction =
         new KToggleAction(i18n("&Resize Playlist Columns Manually"),
@@ -156,7 +159,6 @@ void JuK::setupActions()
     new KAction(i18n("Seek Forward"), "seekForward", 0, m_player, SLOT(seekForward()), actions(), "seekForward");
     new KAction(i18n("Seek Back"),    "seekBack",    0, m_player, SLOT(seekBack()),    actions(), "seekBack");
 
-
     //////////////////////////////////////////////////
     // settings menu
     //////////////////////////////////////////////////
@@ -242,7 +244,7 @@ void JuK::setupGlobalAccels()
     m_accel->updateConnections();
 }
 
-void JuK::processArgs()
+void JuK::slotProcessArgs()
 {
     KCmdLineArgs *args = KCmdLineArgs::parsedArgs();
     QStringList files;
@@ -250,8 +252,7 @@ void JuK::processArgs()
     for(int i = 0; i < args->count(); i++)
         files.append(args->arg(i));
 
-    // TODO: make this work again
-    // m_splitter->open(files);
+    CollectionList::instance()->addFiles(files);
 }
 
 void JuK::createDirs()
@@ -376,6 +377,7 @@ bool JuK::queryExit()
     delete m_systemTray;
     m_systemTray = 0;
 
+    CoverManager::shutdown();
     Cache::instance()->save();
     saveConfig();
 
@@ -421,6 +423,7 @@ void JuK::slotQuit()
 {
     kdDebug(65432) << k_funcinfo << endl;
     m_shuttingDown = true;
+
     kapp->quit();
 }
 
