@@ -59,7 +59,7 @@
 #include "k3bexporter.h"
 #include "upcomingplaylist.h"
 #include "deletedialog.h"
-#include "googlefetcher.h"
+#include "webimagefetcher.h"
 #include "coverinfo.h"
 #include "coverdialog.h"
 #include "tagtransactionmanager.h"
@@ -312,11 +312,12 @@ Playlist::Playlist(PlaylistCollection *collection, const QString &name,
 		   const QString &iconName) :
     KListView(collection->playlistStack(), name.latin1()),
     m_collection(collection),
+    m_fetcher(new WebImageFetcher(this)),
     m_selectedCount(0),
     m_allowDuplicates(false),
     m_polished(false),
     m_applySharedSettings(true),
-    m_mousePressed(false),
+    m_columnWidthModeChanged(false),
     m_disableColumnWidthUpdates(true),
     m_time(0),
     m_widthsDirty(true),
@@ -335,11 +336,12 @@ Playlist::Playlist(PlaylistCollection *collection, const PlaylistItemList &items
 		   const QString &name, const QString &iconName) :
     KListView(collection->playlistStack(), name.latin1()),
     m_collection(collection),
+    m_fetcher(new WebImageFetcher(this)),
     m_selectedCount(0),
     m_allowDuplicates(false),
     m_polished(false),
     m_applySharedSettings(true),
-    m_mousePressed(false),
+    m_columnWidthModeChanged(false),
     m_disableColumnWidthUpdates(true),
     m_time(0),
     m_widthsDirty(true),
@@ -359,11 +361,12 @@ Playlist::Playlist(PlaylistCollection *collection, const QFileInfo &playlistFile
 		   const QString &iconName) :
     KListView(collection->playlistStack()),
     m_collection(collection),
+    m_fetcher(new WebImageFetcher(this)),
     m_selectedCount(0),
     m_allowDuplicates(false),
     m_polished(false),
     m_applySharedSettings(true),
-    m_mousePressed(false),
+    m_columnWidthModeChanged(false),
     m_disableColumnWidthUpdates(true),
     m_time(0),
     m_widthsDirty(true),
@@ -382,11 +385,12 @@ Playlist::Playlist(PlaylistCollection *collection, const QFileInfo &playlistFile
 Playlist::Playlist(PlaylistCollection *collection, bool delaySetup) :
     KListView(collection->playlistStack()),
     m_collection(collection),
+    m_fetcher(new WebImageFetcher(this)),
     m_selectedCount(0),
     m_allowDuplicates(false),
     m_polished(false),
     m_applySharedSettings(true),
-    m_mousePressed(false),
+    m_columnWidthModeChanged(false),
     m_disableColumnWidthUpdates(true),
     m_time(0),
     m_widthsDirty(true),
@@ -849,8 +853,9 @@ void Playlist::slotAddCover(bool retrieveLocal)
         newCover = QPixmap(file.directory() + "/" + file.fileName());
     }
     else {
-        PlaylistItemList::Iterator it=items.begin();
-        newCover = GoogleFetcher((*it)->file()).pixmap();
+        m_fetcher->setFile((*items.begin())->file());
+        m_fetcher->chooseCover();
+        return;
     }
 
     if(newCover.isNull())
@@ -863,6 +868,13 @@ void Playlist::slotAddCover(bool retrieveLocal)
     refreshAlbums(items, newId);
 }
 
+// Called when image fetcher has added a new cover.
+void Playlist::slotCoverChanged(int coverId)
+{
+    kdDebug(65432) << "Refreshing information for newly changed covers.\n";
+    refreshAlbums(selectedItems(), coverId);
+}
+
 void Playlist::slotGuessTagInfo(TagGuesser::Type type)
 {
     KApplication::setOverrideCursor(Qt::waitCursor);
@@ -931,6 +943,7 @@ void Playlist::slotShowPlaying()
     m_collection->raise(l);
 
     l->setSelected(playingItem(), true);
+    l->setCurrentItem(playingItem());
     l->ensureItemVisible(playingItem());
 }
 
@@ -1099,24 +1112,32 @@ bool Playlist::eventFilter(QObject *watched, QEvent *e)
 {
     if(watched == header()) {
 	switch(e->type()) {
+	case QEvent::MouseMove:
+	{
+	    if((static_cast<QMouseEvent *>(e)->state() & LeftButton) == LeftButton &&
+		!action<KToggleAction>("resizeColumnsManually")->isChecked())
+	    {
+		m_columnWidthModeChanged = true;
+
+		action<KToggleAction>("resizeColumnsManually")->setChecked(true);
+		slotColumnResizeModeChanged();
+	    }
+
+	    break;
+	}
 	case QEvent::MouseButtonPress:
 	{
-	    switch(static_cast<QMouseEvent *>(e)->button()) {
-	    case RightButton:
+	    if(static_cast<QMouseEvent *>(e)->button() == RightButton)
 		m_headerMenu->popup(QCursor::pos());
-		break;
-	    case LeftButton:
-		m_mousePressed = true;
-		break;
-	    default:
-		break;
-	    }
+
 	    break;
 	}
 	case QEvent::MouseButtonRelease:
 	{
-	    if(static_cast<QMouseEvent *>(e)->button() == LeftButton)
-		m_mousePressed = false;
+	    if(m_columnWidthModeChanged) {
+		m_columnWidthModeChanged = false;
+		notifyUserColumnWidthModeChanged();
+	    }
 
 	    if(!manualResize() && m_widthsDirty)
 		QTimer::singleShot(0, this, SLOT(slotUpdateColumnWidths()));
@@ -1631,6 +1652,13 @@ void Playlist::setup()
     setItemMargin(3);
 
     connect(header(), SIGNAL(indexChange(int, int, int)), this, SLOT(slotColumnOrderChanged(int, int, int)));
+
+    connect(m_fetcher, SIGNAL(signalCoverChanged(int)), this, SLOT(slotCoverChanged(int)));
+
+    // Prevent list of selected items from changing while internet search is in
+    // progress.
+    connect(this, SIGNAL(selectionChanged()), m_fetcher, SLOT(abortSearch()));
+
     setSorting(1);
 }
 
@@ -2099,7 +2127,7 @@ void Playlist::slotShowRMBMenu(QListViewItem *item, const QPoint &point, int col
 
     if(showEdit)
 	m_rmbMenu->changeItem(m_rmbEditID,
-		i18n("Edit '%1'").arg(columnText(column)));
+		i18n("Edit '%1'").arg(columnText(column + columnOffset())));
 
     m_rmbMenu->setItemVisible(m_rmbEditID, showEdit);
 
@@ -2114,7 +2142,7 @@ void Playlist::slotShowRMBMenu(QListViewItem *item, const QPoint &point, int col
     action("removeCover")->setEnabled(file.coverInfo()->hasCover());
 
     m_rmbMenu->popup(point);
-    m_currentColumn = column;
+    m_currentColumn = column + columnOffset();
 }
 
 void Playlist::slotRenameTag()
@@ -2270,22 +2298,20 @@ void Playlist::slotCreateGroup()
 	new Playlist(m_collection, selectedItems(), name);
 }
 
+void Playlist::notifyUserColumnWidthModeChanged()
+{
+    KMessageBox::information(this,
+			     i18n("Manual column widths have been enabled.  You can "
+				  "switch back to automatic column sizes in the view "
+				  "menu."),
+			     i18n("Manual Column Widths Enabled"),
+			     "ShowManualColumnWidthInformation");
+}
+
 void Playlist::slotColumnSizeChanged(int column, int, int newSize)
 {
     m_widthsDirty = true;
     m_columnFixedWidths[column] = newSize;
-
-    if(m_mousePressed && !action<KToggleAction>("resizeColumnsManually")->isChecked()) {
-	KMessageBox::information(this,
-				 i18n("Manual column widths have been enabled.  You can "
-				      "switch back to automatic column sizes in the view "
-				      "menu."),
-				 i18n("Manual Column Widths Enabled"),
-				 "ShowManualColumnWidthInformation");
-	
-	action<KToggleAction>("resizeColumnsManually")->setChecked(true);
-	slotColumnResizeModeChanged();
-    }
 }
 
 void Playlist::slotInlineCompletionModeChanged(KGlobalSettings::Completion mode)
