@@ -27,6 +27,7 @@
 #include "playlistbox.h"
 #include "playlist.h"
 #include "collectionlist.h"
+#include "covermanager.h"
 #include "dynamicplaylist.h"
 #include "historyplaylist.h"
 #include "upcomingplaylist.h"
@@ -52,7 +53,6 @@ PlaylistBox::PlaylistBox(QWidget *parent, QWidgetStack *playlistStack,
     m_viewModeIndex(0),
     m_hasSelection(false),
     m_doingMultiSelect(false),
-    m_treeViewSetup(false),
     m_dropItem(0),
     m_showTimer(0)
 {
@@ -96,6 +96,7 @@ PlaylistBox::PlaylistBox(QWidget *parent, QWidgetStack *playlistStack,
     m_viewModes.append(new ViewMode(this));
     m_viewModes.append(new CompactViewMode(this));
     m_viewModes.append(new TreeViewMode(this));
+    // m_viewModes.append(new CoverManagerMode(this));
 
     QStringList modeNames;
 
@@ -109,9 +110,15 @@ PlaylistBox::PlaylistBox(QWidget *parent, QWidgetStack *playlistStack,
     p->changeItem(1, SmallIconSet("view_text"), modeNames[1]);
     p->changeItem(2, SmallIconSet("view_tree"), modeNames[2]);
 
+    CollectionList::initialize(this);
+    Cache::loadPlaylists(this);
+
     viewModeAction->setCurrentItem(m_viewModeIndex);
     m_viewModes[m_viewModeIndex]->setShown(true);
 
+    TrackSequenceManager::instance()->setCurrentPlaylist(CollectionList::instance());
+    raise(CollectionList::instance());
+
     viewModeAction->plug(m_contextMenu);
     connect(viewModeAction, SIGNAL(activated(int)), this, SLOT(slotSetViewMode(int)));
 
@@ -128,22 +135,12 @@ PlaylistBox::PlaylistBox(QWidget *parent, QWidgetStack *playlistStack,
     connect(tagManager, SIGNAL(signalAboutToModifyTags()), SLOT(slotFreezePlaylists()));
     connect(tagManager, SIGNAL(signalDoneModifyingTags()), SLOT(slotUnfreezePlaylists()));
 
-    CollectionList::initialize(this);
-    Cache::loadPlaylists(this);
-    TrackSequenceManager::instance()->setCurrentPlaylist(CollectionList::instance());
-    raise(CollectionList::instance());
-
-    // We need to wait until after Collection List is created to set this up.
-
     setupUpcomingPlaylist();
-    performTreeViewSetup();
 
     connect(CollectionList::instance(), SIGNAL(signalNewTag(const QString &, unsigned)),
             this, SLOT(slotAddItem(const QString &, unsigned)));
     connect(CollectionList::instance(), SIGNAL(signalRemovedTag(const QString &, unsigned)),
             this, SLOT(slotRemoveItem(const QString &, unsigned)));
-    connect(m_viewModes[2], SIGNAL(signalPlaylistDestroyed(Playlist*)),
-            this, SLOT(slotTreeViewPlaylistDestroyed(Playlist*)));
 
     QTimer::singleShot(0, object(), SLOT(slotScanFolders()));
     enableDirWatch(true);
@@ -220,30 +217,37 @@ void PlaylistBox::paste()
 
 void PlaylistBox::slotFreezePlaylists()
 {
-    setCanDeletePlaylist(false);
+    setDynamicListsFrozen(true);
 }
 
 void PlaylistBox::slotUnfreezePlaylists()
 {
-    setCanDeletePlaylist(true);
+    setDynamicListsFrozen(false);
 }
 
 void PlaylistBox::setupPlaylist(Playlist *playlist, const QString &iconName)
 {
-    PlaylistCollection::setupPlaylist(playlist, iconName);
-    connect(playlist, SIGNAL(signalPlaylistItemsDropped(Playlist *)), SLOT(slotPlaylistItemsDropped(Playlist *)));
-    if(iconName == "today") {
-	kdDebug(65432) << "Setting up upcoming playlist after Collection List\n";
-	new Item(this, iconName, playlist->name(), playlist, m_playlistDict[CollectionList::instance()]);
-    }
-    else
-	new Item(this, iconName, playlist->name(), playlist);
+    setupPlaylist(playlist, iconName, 0);
 }
 
 void PlaylistBox::setupPlaylist(Playlist *playlist, const QString &iconName, Item *parentItem)
 {
+    connect(playlist, SIGNAL(signalPlaylistItemsDropped(Playlist *)),
+	    SLOT(slotPlaylistItemsDropped(Playlist *)));
+
     PlaylistCollection::setupPlaylist(playlist, iconName);
-    new Item(parentItem, iconName, playlist->name(), playlist);
+
+    if(parentItem)
+	new Item(parentItem, iconName, playlist->name(), playlist);
+    else
+	new Item(this, iconName, playlist->name(), playlist);
+}
+
+void PlaylistBox::removePlaylist(Playlist *playlist)
+{
+    removeNameFromDict(m_playlistDict[playlist]->text(0));
+    removeFileFromDict(playlist->fileName());
+    m_playlistDict.remove(playlist);
 }
 
 ////////////////////////////////////////////////////////////////////////////////
@@ -285,7 +289,7 @@ void PlaylistBox::remove()
 
     if(!files.isEmpty()) {
 	int remove = KMessageBox::warningYesNoCancelList(
-	    this, i18n("Do you want to delete these files from the disk as well?"), files);
+	    this, i18n("Do you want to delete these files from the disk as well?"), files, QString::null, KStdGuiItem::del(), i18n("Keep"));
 
 	if(remove == KMessageBox::Yes) {
 	    QStringList couldNotDelete;
@@ -295,7 +299,7 @@ void PlaylistBox::remove()
 	    }
 
 	    if(!couldNotDelete.isEmpty())
-		KMessageBox::errorList(this, i18n("Could delete these files."), couldNotDelete);
+		KMessageBox::errorList(this, i18n("Could not delete these files."), couldNotDelete);
 	}
 	else if(remove == KMessageBox::Cancel)
 	    return;
@@ -319,9 +323,6 @@ void PlaylistBox::remove()
 	   (*it)->playlist() &&
 	   (!(*it)->playlist()->readOnly()))
 	{
-	    removeNameFromDict((*it)->text(0));
-	    removeFileFromDict((*it)->playlist()->fileName());
-	    m_playlistDict.remove((*it)->playlist());
 	    removeQueue.append((*it)->playlist());
 	}
     }
@@ -349,28 +350,19 @@ void PlaylistBox::remove()
     }
 }
 
-void PlaylistBox::setCanDeletePlaylist(bool canDelete)
+void PlaylistBox::setDynamicListsFrozen(bool frozen)
 {
-    TreeViewMode *treeView = dynamic_cast<TreeViewMode *>(m_viewModes[2]);
-
-    if(treeView)
-	treeView->slotCanDeletePlaylist(canDelete);
-}
-
-void PlaylistBox::slotTreeViewPlaylistDestroyed(Playlist *p)
-{
-    emit signalPlaylistDestroyed(p);
-
-    removeNameFromDict(m_playlistDict[p]->text(0));
-    removeFileFromDict(p->fileName());
-
-    delete m_playlistDict[p];
-    m_playlistDict.remove(p);
+    for(QValueList<ViewMode *>::Iterator it = m_viewModes.begin();
+	it != m_viewModes.end();
+	++it)
+    {
+	(*it)->setDynamicListsFrozen(frozen);
+    }
 }
 
 void PlaylistBox::slotSavePlaylists()
 {
-    kdDebug(65432) << "Auto-saving playlists.\n";
+    kdDebug(65432) << "Auto-saving playlists and covers.\n";
 
     PlaylistList l;
     CollectionList *collection = CollectionList::instance();
@@ -381,6 +373,8 @@ void PlaylistBox::slotSavePlaylists()
     }
 
     Cache::savePlaylists(l);
+    CoverManager::saveCovers();
+
     QTimer::singleShot(600000, this, SLOT(slotSavePlaylists()));
 }
 
@@ -394,20 +388,16 @@ void PlaylistBox::slotShowDropTarget()
     raise(m_dropItem->playlist());
 }
 
-// For the following two function calls, we can forward the slot*Item calls
-// to the tree view mode as long as it has already been setup, whether or
-// not it's actually visible.
-
 void PlaylistBox::slotAddItem(const QString &tag, unsigned column)
 {
-    if(m_treeViewSetup)
-	static_cast<TreeViewMode*>(m_viewModes[2])->slotAddItems(tag, column);
+    for(QValueListIterator<ViewMode *> it = m_viewModes.begin(); it != m_viewModes.end(); ++it)
+	(*it)->addItems(tag, column);
 }
 
 void PlaylistBox::slotRemoveItem(const QString &tag, unsigned column)
 {
-    if(m_treeViewSetup)
-	static_cast<TreeViewMode*>(m_viewModes[2])->slotRemoveItem(tag, column);
+    for(QValueListIterator<ViewMode *> it = m_viewModes.begin(); it != m_viewModes.end(); ++it)
+	(*it)->removeItem(tag, column);
 }
 
 void PlaylistBox::decode(QMimeSource *s, Item *item)
@@ -672,11 +662,6 @@ void PlaylistBox::slotSetViewMode(int index)
     viewMode()->setShown(false);
     m_viewModeIndex = index;
     viewMode()->setShown(true);
-
-    // The following call only does anything if the setup
-    // hasn't already been performed.
-
-    performTreeViewSetup();
 }
 
 void PlaylistBox::setupItem(Item *item)
@@ -685,19 +670,6 @@ void PlaylistBox::setupItem(Item *item)
     viewMode()->queueRefresh();
 }
 
-void PlaylistBox::performTreeViewSetup()
-{
-    if(m_treeViewSetup || m_viewModeIndex != 2)
-	return;
-
-    setSorting(-1);
-    CollectionList::instance()->setupTreeViewEntries(m_viewModes[2]);
-    setSorting(0);
-    sort();
-
-    m_treeViewSetup = true;
-}
-
 void PlaylistBox::setupUpcomingPlaylist()
 {
     KConfigGroup config(KGlobal::config(), "Playlists");
@@ -713,8 +685,8 @@ void PlaylistBox::setupUpcomingPlaylist()
 
 PlaylistBox::Item *PlaylistBox::Item::m_collectionItem = 0;
 
-PlaylistBox::Item::Item(PlaylistBox *listBox, const QString &icon, const QString &text, Playlist *l, Item *after)
-    : QObject(listBox), KListViewItem(listBox, after, text),
+PlaylistBox::Item::Item(PlaylistBox *listBox, const QString &icon, const QString &text, Playlist *l)
+    : QObject(listBox), KListViewItem(listBox, 0, text),
       m_playlist(l), m_text(text), m_iconName(icon), m_sortedFirst(false)
 {
     init();
@@ -808,9 +780,7 @@ void PlaylistBox::Item::init()
     if(m_playlist == CollectionList::instance()) {
 	m_sortedFirst = true;
 	m_collectionItem = this;
-
-	if(dynamic_cast<TreeViewMode *>(list->viewMode()))
-	    static_cast<TreeViewMode *>(list->viewMode())->setupCategories();
+	list->viewMode()->setupDynamicPlaylists();
     }
 
     if(m_playlist == list->historyPlaylist() || m_playlist == list->upcomingPlaylist())
