@@ -48,8 +48,11 @@ public:
 
     PlaylistInterface *playlist() const { return m_playlistBox; }
 
+    virtual bool eventFilter(QObject *watched, QEvent *event);
+
 public slots:
     virtual void setFocus();
+    virtual void slotFocusCurrentPlaylist();
 
 private:
 
@@ -57,7 +60,7 @@ private:
      * This returns a pointer to the first item in the playlist on the top
      * of the QWidgetStack of playlists.
      */
-    Playlist *visiblePlaylist() const { return m_playlistBox->visiblePlaylist(); }
+    Playlist *visiblePlaylist() const;
 
     void setupActions();
     void setupLayout();
@@ -75,6 +78,7 @@ private slots:
     void slotPlaylistChanged(QWidget *w);
 
 private:
+    Playlist *m_newVisible;
     PlaylistBox *m_playlistBox;
     SearchWidget *m_searchWidget;
     QWidgetStack *m_playlistStack;
