@@ -1,18 +1,18 @@
 /* This file is part of the KDE project
  * Copyright (C) 2002 Shane Wright <me@shanewright.co.uk>
  *
- * This program is free softaure; you can redistribute it and/or
+ * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public
- * License as published by the Free Softaure Foundation version 2.
+ * License as published by the Free Software Foundation version 2.
  *
  * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied aurranty of
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; see the file COPYING.  If not, write to
- * the Free Softaure Foundation, Inc., 59 Temple Place - Suite 330,
+ * the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
  * Boston, MA 02111-1307, USA.
  *
  */
@@ -45,13 +45,13 @@ K_EXPORT_COMPONENT_FACTORY(kfile_au, AuFactory( "kfile_au" ))
 
 KAuPlugin::KAuPlugin(QObject *parent, const char *name,
                        const QStringList &args)
-    
+
     : KFilePlugin(parent, name, args)
 {
     KFileMimeTypeInfo* info = addMimeTypeInfo( "audio/basic" );
 
     KFileMimeTypeInfo::GroupInfo* group = 0L;
-    
+
     group = addGroupInfo(info, "Technical", i18n("Technical Details"));
 
     KFileMimeTypeInfo::ItemInfo* item;
@@ -71,11 +71,7 @@ KAuPlugin::KAuPlugin(QObject *parent, const char *name,
 bool KAuPlugin::readInfo( KFileMetaInfo& info, uint what)
 {
     // the file signature, wants to be tidier...
-    char fsig[4];
-    fsig[0] = 0x2e;
-    fsig[1] = 0x73;
-    fsig[2] = 0x6e;
-    fsig[3] = 0x64;
+    const char fsig[] = { 0x2e, 0x73, 0x6e, 0x64 };
 
     // a dword buffer for input
     char inbuf[4];
@@ -87,6 +83,9 @@ bool KAuPlugin::readInfo( KFileMetaInfo& info, uint what)
     uint32_t channels;
     uint16_t bytespersample;
 
+    if ( info.path().isEmpty() ) // remote file
+        return false;
+
     QFile file(info.path());
 
     if (!file.open(IO_ReadOnly))
