@@ -13,7 +13,7 @@
 
   You should have received a copy of the GNU General Public License along
   with this program; if not, write to the Free Software Foundation, Inc.,
-  675 Mass Ave, Cambridge, MA 02139, USA.
+  59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
   The author may be contacted at:
     pfh@yoyo.cc.monash.edu.au
