@@ -1,7 +1,7 @@
 #ifndef WM_CDDA_H
 #define WM_CDDA_H
 /*
- * $Id: wm_cdda.h,v 1.10 2003/07/12 21:24:29 kernalex Exp $
+ * $Id: wm_cdda.h 325595 2004-07-03 19:22:56Z kernalex $
  *
  * This file is part of WorkMan, the civilized CD player library
  * (c) 1991-1997 by Steven Grimm (original author)
@@ -29,29 +29,40 @@
  * Information about a particular block of CDDA data.
  */
 struct cdda_block {
-	unsigned char	status;		/* see below */
-	unsigned char	track;
-	unsigned char	index;
-	unsigned char	minute;
-	unsigned char	second;
-	unsigned char	frame;
+    unsigned char status;
+    unsigned char track;
+    unsigned char index;
+    unsigned char reserved;
 
-	/* Average volume levels, for level meters */
-	unsigned char	lev_chan0;
-	unsigned char	lev_chan1;
-
-	/* Current volume setting (0-255) */
-	unsigned char	volume;
-
-	/* Current balance setting (0-255, 128 = balanced) */
-	unsigned char	balance;
+    int   frame;
+    char *buf;
+    long  buflen;
 };
 
 struct cdda_device {
-  int        fd;
-  const char *devname;
-  char       *buf;
-  long       buflen;
+    int        fd;
+    const char *devname;
+  
+    unsigned char status;
+    unsigned char track;
+    unsigned char index;
+    unsigned char command;
+  
+    int frame;
+    int frames_at_once;
+
+    /* Average volume levels, for level meters */
+    unsigned char lev_chan0;
+    unsigned char lev_chan1;
+
+    /* Current volume setting (0-255) */
+    unsigned char volume;
+
+    /* Current balance setting (0-255, 128 = balanced) */
+    unsigned char balance;
+    
+    struct cdda_block *blocks;
+    int numblocks;
 };
 
 #include "wm_cdrom.h"
@@ -61,15 +72,6 @@ struct cdda_device {
  * cdda_block status codes.
  */
 
-#define WMCDDA_DONE     WM_CDM_TRACK_DONE /* Chunk of data is done playing */
-#define WMCDDA_PLAYING  WM_CDM_PLAYING /* Just played the block in question */
-#define WMCDDA_PAUSED   WM_CDM_PAUSED
-#define WMCDDA_STOPPED  WM_CDM_STOPPED /* Block data invalid; we've just stopped */
-#define WMCDDA_EJECTED  WM_CDM_EJECTED /* Disc ejected or offline */
-
-#define WMCDDA_ACK      WM_CDM_CDDAACK /* Acknowledgement of command from parent */
-#define WMCDDA_ERROR    WM_CDM_CDDAERROR /* Couldn't read CDDA from disc */
-
 /*
  * Enable or disable CDDA building depending on platform capabilities, and
  * determine endianness based on architecture.  (Gross!)
@@ -147,32 +149,31 @@ struct cdda_device {
  */
 #define CDDARETURN(x) if(x && x->cdda == 1) return
 #define IFCDDA(x) if(x && x->cdda == 1)
-int  cdda_get_drive_status( struct wm_drive *d, int oldmode,
-  int *mode, int *pos, int *track, int *ind );
-int  cdda_play( struct wm_drive *d, int start, int end, int realstart );
-int  cdda_pause( struct wm_drive *d );
-int  cdda_stop( struct wm_drive *d );
-int  cdda_eject( struct wm_drive *d );
-int  cdda_set_volume( struct wm_drive *d, int left, int right );
-int  cdda_get_volume( struct wm_drive *d, int *left, int *right );
-void cdda_kill( struct wm_drive *d );
-void cdda_save( struct wm_drive *d, char *filename );
-int  cdda_get_ack( int );
-int  gen_cdda_init( struct wm_drive *d );
+int cdda_get_drive_status(struct wm_drive *d, int oldmode,
+	int *mode, int *pos, int *track, int *ind);
+int cdda_play(struct wm_drive *d, int start, int end, int realstart);
+int cdda_pause(struct wm_drive *d);
+int cdda_stop(struct wm_drive *d);
+int cdda_eject(struct wm_drive *d);
+int cdda_set_volume(struct wm_drive *d, int left, int right);
+int cdda_get_volume(struct wm_drive *d, int *left, int *right);
+void cdda_kill(struct wm_drive *d);
+void cdda_save(struct wm_drive *d, char *filename);
+int cdda_get_ack(int);
+int gen_cdda_init(struct wm_drive *d );
 
-void cdda_set_direction( struct wm_drive *d, int newdir );
-void cdda_set_speed( struct wm_drive *d, int speed );
-void cdda_set_loudness( struct wm_drive *d, int loud );
+void cdda_set_direction(struct wm_drive *d, int newdir);
+void cdda_set_speed(struct wm_drive *d, int speed);
+void cdda_set_loudness(struct wm_drive *d, int loud);
 
 
-int  wmcdda_init(struct cdda_device*, struct cdda_block *block);
-int  wmcdda_open(const char*);
-int  wmcdda_close(struct cdda_device*);
-int  wmcdda_setup(int start, int end, int realstart);
+int wmcdda_init(struct cdda_device*);
+int wmcdda_open(const char*);
+int wmcdda_close(struct cdda_device*);
+int wmcdda_setup(int start, int end, int realstart);
 long wmcdda_read(struct cdda_device*, struct cdda_block *block);
 void wmcdda_speed(int speed);
 void wmcdda_direction(int newdir);
-long wmcdda_normalize(struct cdda_device*, struct cdda_block *block);
 
 #else
  #define CDDARETURN(x)
