@@ -1,7 +1,7 @@
 #ifndef WM_CONFIG_H
 #define WM_CONFIG_H
 /*
- * $Id: wm_config.h 393810 2005-02-28 14:32:02Z aseigo $
+ * $Id: wm_config.h 674869 2007-06-13 10:18:09Z hasso $
  *
  * This file is part of WorkMan, the civilized CD player library
  * (c) 1991-1997 by Steven Grimm (original author)
@@ -139,6 +139,11 @@
 
 #endif /* freebsd */
 
+/* DragonFly */
+#if defined(__DragonFly__)
+#define DEFAULT_CD_DEVICE       "/dev/acd0c"
+#endif
+
 /******************************************************************
  * NetBSD
  ******************************************************************
