@@ -1,5 +1,5 @@
 /*
-  generic interactive controler 
+  generic interactive controller 
   Copyright (C) 1998  Martin Vogt
 
   This program is free software; you can redistribute it and/or modify
@@ -57,7 +57,7 @@ void usage() {
   cout << "Usage : yaf-yuv [w:g:y:f:hr:] <file.raw> [url]"<<endl;
   cout << endl;
   cout << "-w : width of raw yuv stream in pixel"<<endl;
-  cout << "-g : heigth of raw yuv stream in pixel"<<endl;
+  cout << "-g : height of raw yuv stream in pixel"<<endl;
   cout << "-h : help"<<endl;
   cout << "-y : set image Format:"<<endl;
   cout << "                      1   : yuv lum/Cr/Cb"<<endl;
