@@ -10,10 +10,12 @@
 
  */
 
-
-
 #include "command.h"
 
+#include <iostream>
+
+using namespace std;
+
 Command::Command(int id) {
   this->id=id;
   this->intArg=0;
