@@ -29,12 +29,12 @@
 
 
 #include "frame.h"
-
+#include <kdemacros.h>
 #define SCALFACTOR           SHRT_MAX
 #define MP3FRAMESIZE         (2*2*2*32*18)
 
 
-class AudioFrame : public Frame {
+class KDE_EXPORT AudioFrame : public Frame {
 
   int stereo;
   int frequencyHZ;
