@@ -13,6 +13,9 @@
 
 #include "mpegExtension.h"
 
+#include <iostream>
+
+using namespace std;
 
 MpegExtension::MpegExtension() {
   userData=NULL;
