@@ -48,7 +48,7 @@ AudioDataArray::~AudioDataArray() {
     delete audioDataArray[i];
   } 
 
-  delete [] audioDataArray;
+  delete audioDataArray;
 
   abs_thread_mutex_destroy(&writeInMut);
   abs_thread_mutex_destroy(&changeMut);
