@@ -37,7 +37,7 @@ WaitThreadEntry::~WaitThreadEntry() {
 
 
 ThreadQueue::ThreadQueue() {
-  waitThreadEntries=new (WaitThreadEntry* [_MAX_THREAD_IN_QUEUE]);
+  waitThreadEntries=new WaitThreadEntry* [_MAX_THREAD_IN_QUEUE];
   int i;
   for(i=0;i<_MAX_THREAD_IN_QUEUE;i++) {
     waitThreadEntries[i]=new WaitThreadEntry();
@@ -59,7 +59,7 @@ ThreadQueue::~ThreadQueue() {
   for(i=0;i<_MAX_THREAD_IN_QUEUE;i++) {
     delete waitThreadEntries[i];
   }
-  delete waitThreadEntries;
+  delete [] waitThreadEntries;
   abs_thread_mutex_unlock(&queueMut);
   abs_thread_mutex_destroy(&queueMut);
 }
