@@ -40,7 +40,7 @@ static uint32_t arch_accel (void)
 
 #ifndef PIC
 #define cpuid(op,eax,ebx,ecx,edx)	\
-    __asm ("cpuid"			\
+    __asm__ ("cpuid"			\
 	 : "=a" (eax),			\
 	   "=b" (ebx),			\
 	   "=c" (ecx),			\
@@ -49,7 +49,7 @@ static uint32_t arch_accel (void)
 	 : "cc")
 #else	/* PIC version : save ebx */
 #define cpuid(op,eax,ebx,ecx,edx)	\
-    __asm ("pushl %%ebx\n\t"		\
+    __asm__ ("pushl %%ebx\n\t"		\
 	 "cpuid\n\t"			\
 	 "movl %%ebx,%1\n\t"		\
 	 "popl %%ebx"			\
@@ -61,7 +61,7 @@ static uint32_t arch_accel (void)
 	 : "cc")
 #endif
 
-    __asm ("pushfl\n\t"
+    __asm__ ("pushfl\n\t"
 	 "pushfl\n\t"
 	 "popl %0\n\t"
 	 "movl %0,%1\n\t"
@@ -137,7 +137,7 @@ static uint32_t arch_accel (void)
 
     canjump = 1;
 
-    __asm volatile ("mtspr 256,%0" :: "r" (-1));
+    __asm__ volatile ("mtspr 256,%0" :: "r" (-1));
 
     signal (SIGILL, SIG_DFL);
     return MM_ACCEL_PPC_ALTIVEC;
