@@ -16,6 +16,7 @@
  ***************************************************************************/
 
 #include "rgb2yuv32.h"
+#include <iostream>
 
 void rgb2yuv32(unsigned char* rgb, unsigned char* dest)
 {
@@ -101,7 +102,7 @@ void rgb2yuv24bit_mmx(unsigned char* rgbSource,
 		      unsigned char* lum,
 		      unsigned char* cr,
 		      unsigned char* cb,int height, int width) {
-  cout << "RGB->YUV render not compiled for INTEL"<<endl;
+  std::cout << "RGB->YUV render not compiled for INTEL"<<std::endl;
   exit(0);
 }
 
@@ -109,7 +110,7 @@ void rgb2yuv32bit_mmx(unsigned char* rgbSource,
 		      unsigned char* lum,
 		      unsigned char* cr,
 		      unsigned char* cb,int height, int width) {
-  cout << "RGB->YUV render not compiled for INTEL"<<endl;
+  std::cout << "RGB->YUV render not compiled for INTEL"<<std::endl;
   exit(0); 
 }
 
@@ -173,7 +174,7 @@ void rgb2yuv24bit_mmx444_row(unsigned char* rgb, unsigned char* lum, unsigned ch
 	// 24%5 = TEMPV
 
 	__asm__ __volatile__ (
-		"rgb2yuv24_444:\n"
+		"1:\n"
 
 		"movq      (%0), %%mm1\n"  // load G2R2B1G1R1B0G0R0
 		"pxor      %%mm6,   %%mm6\n"  // 0 -> mm6
@@ -356,11 +357,11 @@ void rgb2yuv24bit_mmx444_row(unsigned char* rgb, unsigned char* lum, unsigned ch
 		"movq      %%mm5,   (%3)\n"    // store V
 
 		"sub       $8,       %4\n"
-  		"jnz       rgb2yuv24_444\n"
+  		"jnz       1b\n"
 		"emms\n"
 
 		:
-		: "r" (rgb), "r" (lum), "r" (cr), "r" (cb), "m" (pixel), "m" (buf)
+		: "r" (rgb), "r" (lum), "r" (cr), "r" (cb), "m" (pixel), "m" (buf[0])
 		);
 }
 
@@ -375,7 +376,7 @@ void rgb2yuv24bit_mmx422_row(unsigned char* rgb, unsigned char* lum, unsigned ch
 	// 24%5 = TEMPV
 
 	__asm__ __volatile__ (
-		"rgb2yuv24_422:\n"
+		"1:\n"
 
 		"movq      (%0), %%mm1\n"  // load G2R2B1G1R1B0G0R0
 		"pxor      %%mm6,   %%mm6\n"  // 0 -> mm6
@@ -572,11 +573,11 @@ void rgb2yuv24bit_mmx422_row(unsigned char* rgb, unsigned char* lum, unsigned ch
 		"add       $4,       %3\n"
 		
 		"sub       $8,       %4\n"
-  		"jnz       rgb2yuv24_422\n"
+  		"jnz       1b\n"
 		"emms\n"
 
 		:
-		: "r" (rgb), "r" (lum), "r" (cr), "r" (cb), "m" (pixel), "m" (buf)
+		: "r" (rgb), "r" (lum), "r" (cr), "r" (cb), "m" (pixel), "m" (buf[0])
 		);
 }
 
@@ -591,7 +592,7 @@ void rgb2yuv32bit_mmx422_row(unsigned char* rgb, unsigned char* lum, unsigned ch
 	// 24%5 = TEMPV
 
 	__asm__ __volatile__ (
-		"rgb2yuv32_422:\n"
+		"1:\n"
 
 		// pack rgb
 		// was:	"movq      (%0), %%mm1\n"  // load G2R2B1G1R1B0G0R0
@@ -830,12 +831,12 @@ void rgb2yuv32bit_mmx422_row(unsigned char* rgb, unsigned char* lum, unsigned ch
 		"add       $4,       %3\n"
 		
 		"sub       $8,       %4\n"
-  		"jnz       rgb2yuv32_422\n"
+  		"jnz       1b\n"
 
 		"emms\n"
 
 		:
-		: "r" (rgb), "r" (lum), "r" (cr), "r" (cb), "m" (pixel), "m" (buf)
+		: "r" (rgb), "r" (lum), "r" (cr), "r" (cb), "m" (pixel), "m" (buf[0])
 
 		);
 }
@@ -848,7 +849,7 @@ void rgb2y24bit_mmx_row(unsigned char* rgbSource, unsigned char* lum, int pixel)
 	// 8%3 = TEMPY
 
 	__asm__ __volatile__ (
-		"rgb2y_24:\n"
+		"1:\n"
 
 		"movq      (%0), %%mm1\n"  // load G2R2B1G1R1B0G0R0
 		"pxor      %%mm6,   %%mm6\n"  // 0 -> mm6
@@ -960,11 +961,11 @@ void rgb2y24bit_mmx_row(unsigned char* rgbSource, unsigned char* lum, int pixel)
 		"add       $8,     %1\n"
 		
 		"sub       $8,     %2\n"
-  		"jnz       rgb2y_24\n"
+  		"jnz       1b\n"
 		"emms\n"
 
 		:
-		: "r" (rgbSource), "r" (lum), "m" (pixel), "m" (buf)
+		: "r" (rgbSource), "r" (lum), "m" (pixel), "m" (buf[0])
 		
 		);
 }
@@ -977,7 +978,7 @@ void rgb2y32bit_mmx_row(unsigned char* rgbSource, unsigned char* lum, int pixel)
 	// 8%3 = TEMPY
 
 	__asm__ __volatile__ (
-		"rgb2y_32:\n"
+		"1:\n"
 
 		// pack rgb
 		// was:	"movq      (%0), %%mm1\n"  // load G2R2B1G1R1B0G0R0
@@ -1128,11 +1129,11 @@ void rgb2y32bit_mmx_row(unsigned char* rgbSource, unsigned char* lum, int pixel)
 		"add       $8,     %1\n"
 		
 		"sub       $8,     %2\n"
-  		"jnz       rgb2y_32\n"
+  		"jnz       1b\n"
 		"emms\n"
 
 		:
-		: "r" (rgbSource), "r" (lum), "r" (pixel), "m" (buf)
+		: "r" (rgbSource), "r" (lum), "r" (pixel), "m" (buf[0])
 		
 		);
 }
