@@ -14,7 +14,7 @@
 #ifndef __X11SURFACE_H
 #define __X11SURFACE_H
 
-#include <values.h>
+#include <limits.h>
 #include "xinit.h"
 #include "../surface.h"
 #include "initDisplay.h"
