@@ -23,14 +23,14 @@
 #include <strings.h>
 #endif
 
-
+#include <kdemacros.h>
 
 typedef struct timeval_s {
   long tv_sec;   /* seconds */
   long tv_usec;  /* microseconds */
 } timeval_t;
 
-class TimeWrapper {
+class KDE_EXPORT TimeWrapper {
 
  public:
   TimeWrapper();
