@@ -3,28 +3,43 @@
 
 #include <kdialogbase.h>
 #include <qptrlist.h>
+#include <kdemacros.h>
 
 class CModule;
 
+/**
+ * Noatun configuration dialog
+ **/
 class NoatunPreferences : public KDialogBase
 {
 Q_OBJECT
 friend class CModule;
 
 public:
-	NoatunPreferences(QWidget *parent);
+	/**
+	 * @internal
+	 **/
+	NoatunPreferences(QWidget *);
 
 public:
+	/**
+	 * Display noatun preferences dialog
+	 **/
 	virtual void show();
+	/**
+	 * Display noatun preferences dialog showing @p module
+	 * Useful if you want to display your own plugin configuration tab
+	 **/
+	virtual void show(CModule *module);
 
 protected:
 	virtual void slotOk();
 	virtual void slotApply();
 
 private:
-	void add(CModule *page);
-	void remove(CModule *page);
-	
+	void add(CModule *);
+	void remove(CModule *);
+
 private:
 	class NoatunPreferencesPrivate;
 	NoatunPreferencesPrivate *d;
@@ -32,7 +47,13 @@ private:
 	QPtrList<CModule> mModules;
 };
 
-class CModule : public QWidget
+/**
+ * @short Base class for a configuration sheet that is shown in preferences dialog
+ *
+ * Create your GUI in constructor, reimplement reopen() and save() and
+ * you're all set.
+ **/
+class KDE_EXPORT CModule : public QWidget
 {
 Q_OBJECT
 
