@@ -4,6 +4,7 @@
 #include "kjwidget.h"
 //#include "kjloader.h"
 class KJLoader;
+class VInterpolation;
 
 #include <qobject.h>
 
@@ -12,24 +13,27 @@ class KJEqualizer : public QObject, public KJWidget
 Q_OBJECT
 public:
 	KJEqualizer(const QStringList &, KJLoader *parent);
+	~KJEqualizer(void);
 
 	virtual void mouseMove(const QPoint &pos, bool);
 	virtual bool mousePress(const QPoint&);
-	virtual void paint(QPainter *, const QRect &rect);
+	virtual void paint(QPainter *p, const QRect &rect);
 	int barNum(const QPoint &pos) const;
 	int level(const QPoint &pos) const;
 
 public slots:
-	void updateBuffer();
+	void slotUpdateBuffer();
 
 private:
 	int mBands;
 	int mXSpace;
 
-	int mXSize;
-	int mNumber;
-	QPixmap mBars;
-	QPixmap mBuffer;
+	int mBandWidth;
+	int mBandHalfHeight;
+	QPixmap mBars; // holds all slider images
+	QPixmap *mBack; // holds background of EQ for easy repaint
+	QPixmap *mView; // holds prepared img of all sliders
+	VInterpolation *mInterpEq;
 };
 
 #endif
