@@ -1,7 +1,7 @@
 /***************************************************************************
 	kjvis.cpp  -  Visualizations used in the KJfol-GUI
 	--------------------------------------
-	Maintainer: Stefan Gehn <sgehn@gmx.net>
+	Maintainer: Stefan Gehn <metz AT gehn.net>
 
  ***************************************************************************/
 
@@ -26,12 +26,15 @@
 // noatun includes
 #include <noatun/player.h>
 
+#define _KJ_GRADIENT_DIFF 130
+
 /*******************************************
- * KJVisScope
+ * KJFFTScope
  *******************************************/
 
 void KJVisScope::swapScope(Visuals newOne)
 {
+	//kdDebug(66666) << k_funcinfo << endl;
 	QStringList line = parent()->item("analyzerwindow");
 	KJLoader *p=parent();
 	p->removeChild(this);
@@ -46,10 +49,14 @@ void KJVisScope::swapScope(Visuals newOne)
 		w = new KJNullScope(line, p);
 		break;
 	case FFT:
-		w = new KJVis(line, p);
+		w = new KJFFT(line, p);
+		break;
+	case StereoFFT:
+		w = new KJStereoFFT(line, p);
 		break;
 	case Mono:
 		w = new KJScope(line, p);
+		break;
 	};
 
 	p->addChild(w);
@@ -108,17 +115,17 @@ void KJNullScope::readConfig()
 
 
 /*************************************************
- * KJVis - Analyzer like visualization
+ * KJFFT - Analyzer like visualization, mono
  *************************************************/
 
-KJVis::KJVis(const QStringList &l, KJLoader *parent)
-	: KJVisScope(parent), MonoFFTScope(30), mGradient(0)
+KJFFT::KJFFT(const QStringList &l, KJLoader *parent)
+	: KJVisScope(parent), MonoFFTScope(50), mGradient(0)
 {
 	int x = l[1].toInt();
 	int y = l[2].toInt();
 	int xs = l[3].toInt()-x;
 	int ys = l[4].toInt()-y;
-	
+
 	// each bar will be 1px wide
 	mMultiples=1;
 
@@ -142,18 +149,16 @@ KJVis::KJVis(const QStringList &l, KJLoader *parent)
 
 	// create a gradient for the bars going from 30% lighter to 30% darker than mColor
 	mGradient = new KPixmap ( QSize(xs,ys) );
-	KPixmapEffect::gradient ( *mGradient, mColor.light(130), mColor.dark(130), KPixmapEffect::VerticalGradient );
-	
+	KPixmapEffect::gradient ( *mGradient, mColor.light(_KJ_GRADIENT_DIFF),
+		mColor.dark(_KJ_GRADIENT_DIFF), KPixmapEffect::VerticalGradient );
+
 	setRect (x,y,xs,ys);
-
 	setBands(magic(xs/mMultiples));
-
 	readConfig(); // read our config settings
-
 	start();
 }
 
-void KJVis::scopeEvent(float *d, int size)
+void KJFFT::scopeEvent(float *d, int size)
 {
 	if ( !napp->player()->isPlaying() ) // don't draw if we aren't playing (either paused or stopped)
 	{
@@ -201,7 +206,7 @@ void KJVis::scopeEvent(float *d, int size)
 	repaint();
 }
 
-void KJVis::paint(QPainter *p, const QRect &)
+void KJFFT::paint(QPainter *p, const QRect &)
 {
 	// put that thing on screen
 	if ( !napp->player()->isStopped() )
@@ -209,12 +214,12 @@ void KJVis::paint(QPainter *p, const QRect &)
 }
 
 
-bool KJVis::mousePress(const QPoint &)
+bool KJFFT::mousePress(const QPoint &)
 {
 	return true;
 }
 
-void KJVis::mouseRelease(const QPoint &, bool in)
+void KJFFT::mouseRelease(const QPoint &, bool in)
 {
 	if (!in) // only do something if users is still inside the button
 		return;
@@ -224,9 +229,9 @@ void KJVis::mouseRelease(const QPoint &, bool in)
 	swapScope(Mono);
 }
 
-void KJVis::readConfig()
+void KJFFT::readConfig()
 {
-//	kdDebug(66666) << "[KJVis] readConfig()" << endl;
+//	kdDebug(66666) << "[KJFFT] readConfig()" << endl;
 	Visuals v = (Visuals) KJLoader::kjofol->prefs()->visType();
 	if ( v != FFT )
 	{
@@ -240,12 +245,162 @@ void KJVis::readConfig()
 	setInterval( mTimerValue );
 }
 
+
+/*************************************************
+ * KJStereoFFT - Analyzer like visualization, stereo
+ *************************************************/
+
+KJStereoFFT::KJStereoFFT(const QStringList &l, KJLoader *parent)
+	: KJVisScope(parent), StereoFFTScope(50), mGradient(0)
+{
+	//kdDebug(66666) << k_funcinfo << endl;
+
+	int x = l[1].toInt();
+	int y = l[2].toInt();
+	int xs = l[3].toInt()-x;
+	int ys = l[4].toInt()-y;
+
+	// each bar will be 1px wide
+	mMultiples=1;
+
+	if ( parent->exist("analyzercolor") )
+	{
+		QStringList &col = parser()["analyzercolor"];
+		mColor.setRgb ( col[1].toInt(), col[2].toInt(), col[3].toInt() );
+	}
+	else // TODO: what should be default colors for Vis?
+	{
+		mColor.setRgb ( 255, 255, 255 ); // white is default
+	}
+
+	// background under vis
+	QPixmap tmp  = parent->pixmap(parent->item("backgroundimage")[1]);
+	mBack = new KPixmap ( QSize(xs,ys) );
+	bitBlt( mBack, 0, 0, &tmp, x, y, xs, ys, Qt::CopyROP );
+
+	mAnalyzer = new KPixmap ( QSize(xs,ys) );
+	bitBlt( mAnalyzer, 0, 0, &tmp, x, y, xs, ys, Qt::CopyROP );
+
+	// create a gradient for the bars going from 30% lighter to 30% darker than mColor
+	mGradient = new KPixmap ( QSize(xs,ys) );
+	KPixmapEffect::gradient ( *mGradient, mColor.light(_KJ_GRADIENT_DIFF),
+		mColor.dark(_KJ_GRADIENT_DIFF), KPixmapEffect::VerticalGradient );
+
+	setRect (x,y,xs,ys);
+	setBands(magic(xs/mMultiples));
+	readConfig(); // read our config settings
+	start();
+}
+
+void KJStereoFFT::scopeEvent(float *left, float *right, int len)
+{
+	if ( !napp->player()->isPlaying() ) // don't draw if we aren't playing (either paused or stopped)
+	{
+		if ( napp->player()->isStopped() ) // clear vis-window if playing has been stopped
+			parent()->repaint(rect(), false);
+		return;
+	}
+
+	unsigned int h = rect().height();
+	int hh = (int)(rect().height()/2);
+
+	QBitmap mGradientMask ( rect().width(), h, true );
+	QPainter mask( &mGradientMask );
+
+	float *start = left;
+	float *end = left + len;
+	float n = 0.0;
+	int amp = 0;
+	int x = 0;
+
+	// loop creating the mask for vis-gradient
+	for ( ; start < end; ++start )
+	{
+		n = log((*start)+1) * (float)hh * 5;
+		amp = (int)n;
+
+		// range check
+		if ( amp < 0 ) amp = 0;
+		else if ( amp > hh ) amp = hh;
+
+		// make a part of the analyzer-gradient visible
+		mask.fillRect ( x, (h-amp), mMultiples, amp, Qt::color1 );
+		x += mMultiples;
+	}
+	// done creating our mask
+
+
+	start = right;
+	end = right + len;
+	x = 0;
+	// loop creating the mask for vis-gradient
+	for ( ; start < end; ++start )
+	{
+		n = log((*start)+1) * (float)hh * 5;
+		amp = (int)n;
+
+		// range check
+		if ( amp < 0 ) amp = 0;
+		else if ( amp > hh ) amp = hh;
+
+		// make a part of the analyzer-gradient visible
+		mask.fillRect ( x, 0, mMultiples, amp, Qt::color1 );
+		x += mMultiples;
+	}
+
+
+	// draw background of vis into it
+	bitBlt ( mAnalyzer, 0, 0, mBack, 0, 0, -1, -1, Qt::CopyROP );
+
+	// draw the analyzer
+	mGradient->setMask(mGradientMask);
+	bitBlt ( mAnalyzer, 0, 0, mGradient, 0, 0, -1, -1, Qt::CopyROP );
+
+	repaint();
+}
+
+void KJStereoFFT::paint(QPainter *p, const QRect &)
+{
+	// put that thing on screen
+	if ( !napp->player()->isStopped() )
+		bitBlt ( p->device(), rect().topLeft(), mAnalyzer, QRect(0,0,-1,-1), Qt::CopyROP );
+}
+
+bool KJStereoFFT::mousePress(const QPoint &)
+{
+	return true;
+}
+
+void KJStereoFFT::mouseRelease(const QPoint &, bool in)
+{
+	if (!in) // only do something if users is still inside the button
+		return;
+	stop();
+	parent()->repaint(rect(), false);
+	swapScope(Null);
+}
+
+void KJStereoFFT::readConfig()
+{
+	//kdDebug(66666) << k_funcinfo << endl;
+	Visuals v = (Visuals) KJLoader::kjofol->prefs()->visType();
+	if ( v != StereoFFT )
+	{
+		stop();
+		parent()->repaint(rect(), false);
+		swapScope ( v );
+		return;
+	}
+	setInterval(KJLoader::kjofol->prefs()->visTimerValue());
+}
+
+
 /*************************************************
  * KJScope - oscilloscope like visualization
  *************************************************/
 
 KJScope::KJScope(const QStringList &l, KJLoader *parent)
-	: KJVisScope(parent), MonoScope(30)/*, blurnum(0), mOsci(0)*/
+	: KJVisScope(parent), MonoScope(50)/*, blurnum(0), mOsci(0)*/
 {
 	int x=l[1].toInt();
 	int y=l[2].toInt();
@@ -274,13 +429,14 @@ KJScope::KJScope(const QStringList &l, KJLoader *parent)
 
 	// create a gradient
 	mGradient = new KPixmap ( QSize(xs,ys) );
-	KPixmapEffect::gradient ( *mGradient, mColor.light(130), mColor.dark(130), KPixmapEffect::VerticalGradient );
+	KPixmapEffect::gradient ( *mGradient, mColor.light(_KJ_GRADIENT_DIFF),
+		mColor.dark(_KJ_GRADIENT_DIFF), KPixmapEffect::VerticalGradient );
 
 	setRect ( x, y, xs, ys );
 
 	// set the samplewidth to the largest integer divisible by mWidth
 	setSamples ( xs );
-	
+
 	readConfig();
 	start();
 }
@@ -362,10 +518,9 @@ void KJScope::mouseRelease(const QPoint &, bool in)
 
 	stop();
 	parent()->repaint(rect(), false);
-	swapScope(Null);
+	swapScope(/*Null*/ StereoFFT);
 }
 
-
 void KJScope::readConfig()
 {
 //	kdDebug(66666) << "[KJScope] readConfig()" << endl;
@@ -381,4 +536,3 @@ void KJScope::readConfig()
 	mTimerValue = KJLoader::kjofol->prefs()->visTimerValue();
 	setInterval( mTimerValue );
 }
-
