@@ -9,7 +9,7 @@
 
 extern "C"
 {
-	Plugin *create_plugin()
+	KDE_EXPORT Plugin *create_plugin()
 	{
 		return new Monoscope();
 	}
