@@ -15,17 +15,12 @@
 #define __WINSKINVIS_H
 
 #include <qobject.h>
-#include <iostream.h>
 
 // These are needed for the Visualisation class 
 #include <soundserver.h>
 #include "noatunarts/noatunarts.h"
 #include "noatun/plugin.h"
 
-
-
-#ifdef _COMPILE_WINSKINVIS
-
 #include "vis/winskinvis.h"
 
 class WinSkinVis : public QObject, public Visualization {
@@ -40,22 +35,20 @@ class WinSkinVis : public QObject, public Visualization {
   * should never need to reimplement this yourself
   **/
   void timeout();
-  float* getCurrentPeaks();
+  float* currentPeaks();
 
  signals:
-  void dorepaint();
+  void doRepaint();
 
  private:
-  void scopeEvent(float* spectrum, int size);
+  bool initServerObject();
+  void scopeEvent(float* spectrum, unsigned int size);
 
-  Noatun::WinSkinFFT* winSkinFFT;
-  long mId;
-  float* currentPeaks;
+  Noatun::WinSkinFFT* m_winSkinFFT;
+  long m_id;
+  float* m_currentPeaks;
 
 
 };
 
 #endif
-// _COMPILE_WINSKINVIS
-
-#endif
